BaseModule class

Implementers

Constructors

BaseModule(RpcProvider provider)

Properties

hashCode → int
The hash code for this object.
no setterinherited
provider ↔ RpcProvider
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendToProvider({required Enum method, List? params}) → Future<JavaScriptMessage>
Returns
sendToProviderWithMap({required Enum method, Map<String, dynamic>? params}) → Future<JavaScriptMessage>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited