BlockchainModule class

Inheritance

Constructors

BlockchainModule(dynamic provider, SupportedBlockchain blockchainName)

Properties

blockchainName ↔ SupportedBlockchain
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
provider ↔ RpcProvider
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendToProvider({required Enum method, List? params}) → Future<JavaScriptMessage>
Returns
inherited
sendToProviderWithMap({required Enum method, Map<String, dynamic>? params}) → Future<JavaScriptMessage>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited